#[non_exhaustive]pub enum CacheDirectoryProblem {
Symlink,
NotDirectory,
WrongOwner,
GroupOrOtherAccessible,
}Expand description
Privacy or type problem found in an existing personal-cache directory.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Symlink
The directory path is a symbolic link.
NotDirectory
The path exists but is not a directory.
WrongOwner
The directory is not owned by the current user.
GroupOrOtherAccessible
The directory grants group or other access.