#[non_exhaustive]pub enum CachePathProblem {
MissingParentDirectory,
}Expand description
Problem found in an explicitly supplied cache entry path.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingParentDirectory
The supplied cache entry path has no parent directory.