#[non_exhaustive]pub enum RawThumbnailPixelFormat {
Rgb8,
Rgba8,
}Expand description
Explicit raw pixel format accepted by raw thumbnail install APIs.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rgb8
Three 8-bit channels per pixel in red, green, blue order.
Rgba8
Four 8-bit channels per pixel in red, green, blue, alpha order.