SharedCacheEntryOutcome

Enum SharedCacheEntryOutcome 

#[non_exhaustive]
pub enum SharedCacheEntryOutcome { FullyVerified, MetadataIncomplete, Invalid(Vec<CacheEntryProblem>), Unverifiable(Vec<CacheEntryProblem>), }
Validation state for a shared cache entry inspection.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


FullyVerified

Required metadata and PNG constraints are fully verified.



MetadataIncomplete

Standard-optional shared freshness metadata is absent.



Invalid(Vec<CacheEntryProblem>)

The entry is invalid for the requested shared context.



Unverifiable(Vec<CacheEntryProblem>)

Caller-supplied shared original facts are insufficient to verify the entry.