#[non_exhaustive]pub enum SharedThumbnailLookup<T> {
FullyVerified(T),
MetadataIncomplete(T),
Missing,
Invalid(Vec<CacheEntryProblem>),
Unverifiable(Vec<CacheEntryProblem>),
}Expand description
Result of a validated shared thumbnail repository lookup.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FullyVerified(T)
The cache entry exists and required metadata and PNG constraints are fully verified.
MetadataIncomplete(T)
The cache entry is otherwise usable but lacks standard-optional shared freshness metadata.
Missing
The computed shared cache path does not exist.
Invalid(Vec<CacheEntryProblem>)
The cache entry exists but is invalid for the requested context.
Unverifiable(Vec<CacheEntryProblem>)
Caller-supplied shared original facts are insufficient to verify the entry.