#[non_exhaustive]pub enum ThumbnailSize {
Normal,
Large,
XLarge,
XxLarge,
}Expand description
A standard Freedesktop thumbnail size directory.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Normal
128px thumbnail cache directory.
Large
256px thumbnail cache directory.
XLarge
512px thumbnail cache directory.
XxLarge
1024px thumbnail cache directory.
Implementations
Sourceimpl ThumbnailSize
impl ThumbnailSize
Sourcepub const fn directory_name(self) -> &'static str
pub const fn directory_name(self) -> &'static str
Returns the standard cache directory name for this size.
Sourcepub const fn max_dimension(self) -> u32
pub const fn max_dimension(self) -> u32
Returns the maximum width and height for this namespace in pixels.