pub struct SharedCacheEntryInspection { /* private fields */ }Expand description
Read-only inspection facts for an existing shared thumbnail repository entry.
Implementations
Sourcepub const fn outcome(&self) -> &SharedCacheEntryOutcome
pub const fn outcome(&self) -> &SharedCacheEntryOutcome
Returns the shared validation or inspection outcome.
Returns the shared relative URI used for hashing and metadata comparison.
Sourcepub const fn timestamps(&self) -> &ThumbnailTimestamps
pub const fn timestamps(&self) -> &ThumbnailTimestamps
Returns timestamp facts.
Sourcepub const fn size(&self) -> ThumbnailSize
pub const fn size(&self) -> ThumbnailSize
Returns the successful-thumbnail size namespace.
Sourcepub const fn metadata(&self) -> Option<&ThumbnailMetadata>
pub const fn metadata(&self) -> Option<&ThumbnailMetadata>
Returns parsed metadata when the entry was a readable PNG.
Sourcepub fn into_parts(self) -> SharedCacheEntryInspectionParts
pub fn into_parts(self) -> SharedCacheEntryInspectionParts
Splits this inspection into its owned facts.