pub struct SharedToPersonalThumbnailMaterializationRequest { /* private fields */ }Expand description
Owned shared-to-personal fallback materialization request for async adapters.
Constructing this request does not perform filesystem I/O. Validation and materialization
happen only when Self::materialize_path or Self::materialize_png_bytes is called.
Implementations
Sourcepub fn new(
personal_root: PersonalCacheRoot,
shared_context: SharedRepositoryContext,
original_facts: SharedOriginalFacts,
size: ThumbnailSize,
) -> Self
pub fn new( personal_root: PersonalCacheRoot, shared_context: SharedRepositoryContext, original_facts: SharedOriginalFacts, size: ThumbnailSize, ) -> Self
Creates an owned shared-to-personal materialization request.
Sourcepub fn materialize_path(
self,
) -> Result<SharedThumbnailLookup<MaterializedThumbnailPath>>
pub fn materialize_path( self, ) -> Result<SharedThumbnailLookup<MaterializedThumbnailPath>>
Materializes the requested shared thumbnail into the personal cache and returns its path.
Errors
Returns the same errors as
PersonalCacheRoot::materialize_shared_thumbnail_returning_path.
Sourcepub fn materialize_png_bytes(
self,
) -> Result<SharedThumbnailLookup<MaterializedThumbnailPngBytes>>
pub fn materialize_png_bytes( self, ) -> Result<SharedThumbnailLookup<MaterializedThumbnailPngBytes>>
Materializes the requested shared thumbnail into the personal cache and returns final PNG bytes.
Errors
Returns the same errors as
PersonalCacheRoot::materialize_shared_thumbnail_returning_png_bytes.
Sourcepub fn into_parts(self) -> SharedToPersonalThumbnailMaterializationRequestParts
pub fn into_parts(self) -> SharedToPersonalThumbnailMaterializationRequestParts
Splits this request into its owned parts.