ThumbnailMetadata

Struct ThumbnailMetadata 

pub struct ThumbnailMetadata { /* private fields */ }
Freedesktop thumbnail PNG text metadata.

Implementations

Source

impl ThumbnailMetadata

pub fn get(&self, key: &str) -> Option<&str>

Returns a raw metadata value by key.

pub fn iter(&self) -> impl Iterator<Item = (&str, &str)> + '_

Iterates over raw metadata key/value pairs.

pub fn thumb_uri(&self) -> Option<&str>

Returns Thumb::URI when present.

pub fn thumb_mtime_lossy(&self) -> Option<UnixMtimeSeconds>

Returns parsed Thumb::MTime, or None when it is missing or syntactically invalid.

pub fn try_thumb_mtime(&self) -> Result<Option<UnixMtimeSeconds>>

Returns parsed Thumb::MTime, distinguishing missing metadata from invalid syntax.

Errors

Returns an error when Thumb::MTime is present but not a non-negative whole Unix epoch second value.

pub fn thumb_size_lossy(&self) -> Option<u64>

Returns parsed Thumb::Size, or None when it is missing or syntactically invalid.

pub fn try_thumb_size(&self) -> Result<Option<u64>>

Returns parsed Thumb::Size, distinguishing missing metadata from invalid syntax.

Errors

Returns an error when Thumb::Size is present but is not an unsigned integer.

pub fn thumb_mime_type(&self) -> Option<&str>

Returns Thumb::Mimetype when present.