pub struct UnixMtimeSeconds { /* private fields */ }Expand description
Whole Unix epoch seconds used by Thumb::MTime.
Implementations
Sourceimpl UnixMtimeSeconds
impl UnixMtimeSeconds
Sourcepub const fn new(seconds: u64) -> Self
pub const fn new(seconds: u64) -> Self
Creates a timestamp from non-negative whole Unix epoch seconds.
Sourcepub const fn try_from_i64(seconds: i64) -> Result<Self>
pub const fn try_from_i64(seconds: i64) -> Result<Self>
Creates a timestamp from signed whole Unix epoch seconds.
Errors
Returns an error when seconds is negative.
Sourcepub fn from_system_time(time: SystemTime) -> Result<Self>
pub fn from_system_time(time: SystemTime) -> Result<Self>
Converts a SystemTime to whole non-negative Unix epoch seconds.
Errors
Returns an error when time is before the Unix epoch.