pub struct MaterializedThumbnailPath { /* private fields */ }Expand description
Path result of explicit fallback materialization into the personal cache.
Implementations
Sourceimpl MaterializedThumbnailPath
impl MaterializedThumbnailPath
Sourcepub fn target_path(&self) -> &Path
pub fn target_path(&self) -> &Path
Returns the requested personal-cache target path.
Sourcepub fn source_path(&self) -> &Path
pub fn source_path(&self) -> &Path
Returns the source cache path used for materialization.
Sourcepub const fn requested_size(&self) -> ThumbnailSize
pub const fn requested_size(&self) -> ThumbnailSize
Returns the requested target size namespace.
Sourcepub const fn source_size(&self) -> ThumbnailSize
pub const fn source_size(&self) -> ThumbnailSize
Returns the source size namespace.
Sourcepub fn into_parts(self) -> MaterializedThumbnailPathParts
pub fn into_parts(self) -> MaterializedThumbnailPathParts
Splits this result into its owned target path, source path, size facts, and write status.