pub struct PersonalThumbnailMaterializationRequest { /* private fields */ }Expand description
Owned personal-cache fallback materialization request for async or runtime-specific adapters.
Constructing this request does not perform filesystem I/O. Validation and materialization
happen only when Self::materialize_path or Self::materialize_png_bytes is called.
Implementations
Sourceimpl PersonalThumbnailMaterializationRequest
impl PersonalThumbnailMaterializationRequest
Sourcepub fn new(
root: PersonalCacheRoot,
original: ReadablePersonalOriginalIdentity,
size: ThumbnailSize,
) -> Self
pub fn new( root: PersonalCacheRoot, original: ReadablePersonalOriginalIdentity, size: ThumbnailSize, ) -> Self
Creates an owned personal-cache materialization request.
Sourcepub fn materialize_path(
self,
) -> Result<PersonalThumbnailLookup<MaterializedThumbnailPath>>
pub fn materialize_path( self, ) -> Result<PersonalThumbnailLookup<MaterializedThumbnailPath>>
Materializes the requested personal namespace and returns its path.
Errors
Returns the same errors as
PersonalCacheRoot::materialize_thumbnail_from_larger_cache_returning_path.
Sourcepub fn materialize_png_bytes(
self,
) -> Result<PersonalThumbnailLookup<MaterializedThumbnailPngBytes>>
pub fn materialize_png_bytes( self, ) -> Result<PersonalThumbnailLookup<MaterializedThumbnailPngBytes>>
Materializes the requested personal namespace and returns final PNG bytes.
Errors
Returns the same errors as
PersonalCacheRoot::materialize_thumbnail_from_larger_cache_returning_png_bytes.
Sourcepub fn into_parts(self) -> PersonalThumbnailMaterializationRequestParts
pub fn into_parts(self) -> PersonalThumbnailMaterializationRequestParts
Splits this request into its owned parts.